StdLog — biskit 3.0.0a1 documentation

# StdLog

class `biskit.` `StdLog`

  Bases: `biskit.logFile.LogFile`

  Print to std out.

  Methods Overview

  `__init__` |
  param fname: | name of log file :type fname: str :param mode: mode (default: w) :type mode: str
  `add` | Add new line to logfile and flush
  `add_nobreak` | Add new line without creating a linebreak to logfile and flush
  `f` | Open file only when needed for first time.
  `write` | Synonym for add_nobreak.
  `writeln` | Synonym for add.

  ## StdLog Method & Attribute Details

  `__init__`()

    Parameters: | fname (str) – name of log file mode (str) – mode (default: w)